using System;
using System.Collections.Generic;
using System.Text;

namespace TestSearch
{
    /// <summary>
    /// interface for an indexing collection class
    /// </summary>
    /// <typeparam name="T">Type of values stored</typeparam>
    /// <remarks>Index keys are always strings, so as to allow substrings.</remarks>
    interface IIndexer<T>
    {
        /// <summary>
        /// Adds an item to the index
        /// </summary>
        /// <param name="key">The key.</param>
        /// <param name="value">The value.</param>
        void AddItem(string key, T value, UInt32 sortOrder);
        /// <summary>
        /// Lookups the specified sub key.
        /// </summary>
        /// <param name="subKey">The sub key.</param>
        /// <returns>A list of values that match the subkey</returns>
        IList<T> Lookup(string subKey);
        /// <summary>
        /// Call when indexing is finished to perform any necessary clean-up code
        /// </summary>
        void FinishIndex();

    }
}
